# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.electrum_raw_transaction import ElectrumRawTransaction  # noqa: E501
from mainnet.rest import ApiException

class TestElectrumRawTransaction(unittest.TestCase):
    """ElectrumRawTransaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ElectrumRawTransaction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.electrum_raw_transaction.ElectrumRawTransaction()  # noqa: E501
        if include_optional :
            return ElectrumRawTransaction(
                blockhash = '0', 
                blocktime = 1.337, 
                confirmations = 1.337, 
                hash = '0', 
                hex = '0', 
                locktime = 1.337, 
                size = 1.337, 
                time = 1.337, 
                txid = '0', 
                version = 1.337, 
                vin = [
                    mainnet.models.electrum_raw_transaction_vin.ElectrumRawTransaction_vin(
                        script_sig = mainnet.models.electrum_raw_transaction_script_sig.ElectrumRawTransaction_scriptSig(
                            asm = '0', 
                            hex = '0', ), 
                        sequence = 1.337, 
                        txid = '0', 
                        vout = 1.337, 
                        value = 1.337, 
                        address = '0', )
                    ], 
                vout = [
                    mainnet.models.electrum_raw_transaction_vout.ElectrumRawTransaction_vout(
                        n = 1.337, 
                        script_pub_key = mainnet.models.electrum_raw_transaction_script_pub_key.ElectrumRawTransaction_scriptPubKey(
                            addresses = [
                                '0'
                                ], 
                            asm = '0', 
                            hex = '0', 
                            req_sigs = 1.337, 
                            type = '0', ), 
                        value = 1.337, )
                    ]
            )
        else :
            return ElectrumRawTransaction(
        )

    def testElectrumRawTransaction(self):
        """Test ElectrumRawTransaction"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class GetXpubKeyInfoResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'str',
        'depth': 'float',
        'parent_fingerprint': 'str',
        'data': 'str',
        'chain': 'object'
    }

    attribute_map = {
        'version': 'version',
        'depth': 'depth',
        'parent_fingerprint': 'parentFingerprint',
        'data': 'data',
        'chain': 'chain'
    }

    def __init__(self, version=None, depth=None, parent_fingerprint=None, data=None, chain=None, local_vars_configuration=None):  # noqa: E501
        """GetXpubKeyInfoResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._depth = None
        self._parent_fingerprint = None
        self._data = None
        self._chain = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if depth is not None:
            self.depth = depth
        if parent_fingerprint is not None:
            self.parent_fingerprint = parent_fingerprint
        if data is not None:
            self.data = data
        self.chain = chain

    @property
    def version(self):
        """Gets the version of this GetXpubKeyInfoResponse.  # noqa: E501


        :return: The version of this GetXpubKeyInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GetXpubKeyInfoResponse.


        :param version: The version of this GetXpubKeyInfoResponse.  # noqa: E501
        :type version: str
        """

        self._version = version

    @property
    def depth(self):
        """Gets the depth of this GetXpubKeyInfoResponse.  # noqa: E501


        :return: The depth of this GetXpubKeyInfoResponse.  # noqa: E501
        :rtype: float
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this GetXpubKeyInfoResponse.


        :param depth: The depth of this GetXpubKeyInfoResponse.  # noqa: E501
        :type depth: float
        """

        self._depth = depth

    @property
    def parent_fingerprint(self):
        """Gets the parent_fingerprint of this GetXpubKeyInfoResponse.  # noqa: E501

        the first four bytes of the public key as hex  # noqa: E501

        :return: The parent_fingerprint of this GetXpubKeyInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_fingerprint

    @parent_fingerprint.setter
    def parent_fingerprint(self, parent_fingerprint):
        """Sets the parent_fingerprint of this GetXpubKeyInfoResponse.

        the first four bytes of the public key as hex  # noqa: E501

        :param parent_fingerprint: The parent_fingerprint of this GetXpubKeyInfoResponse.  # noqa: E501
        :type parent_fingerprint: str
        """

        self._parent_fingerprint = parent_fingerprint

    @property
    def data(self):
        """Gets the data of this GetXpubKeyInfoResponse.  # noqa: E501

        the public key as hex  # noqa: E501

        :return: The data of this GetXpubKeyInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this GetXpubKeyInfoResponse.

        the public key as hex  # noqa: E501

        :param data: The data of this GetXpubKeyInfoResponse.  # noqa: E501
        :type data: str
        """

        self._data = data

    @property
    def chain(self):
        """Gets the chain of this GetXpubKeyInfoResponse.  # noqa: E501

        The chain code, 32 bytes of entrophy extended for the public key  # noqa: E501

        :return: The chain of this GetXpubKeyInfoResponse.  # noqa: E501
        :rtype: object
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this GetXpubKeyInfoResponse.

        The chain code, 32 bytes of entrophy extended for the public key  # noqa: E501

        :param chain: The chain of this GetXpubKeyInfoResponse.  # noqa: E501
        :type chain: object
        """

        self._chain = chain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetXpubKeyInfoResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetXpubKeyInfoResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.smart_bch_contract_response import SmartBchContractResponse  # noqa: E501
from mainnet.rest import ApiException

class TestSmartBchContractResponse(unittest.TestCase):
    """SmartBchContractResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SmartBchContractResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.smart_bch_contract_response.SmartBchContractResponse()  # noqa: E501
        if include_optional :
            return SmartBchContractResponse(
                contract_id = 'smartbchcontract:mainnet:0xdac17f958d2ee523a2206206994597c13d831ec7:WyJmdW5jdGlvbiBuYW1lKCkgdmlldyByZXR1cm5zIChzdHJpbmcpIiwiZnVuY3Rpb24gc3ltYm9sKCkgdmlldyByZXR1cm5zIChzdHJpbmcpIiwiZnVuY3Rpb24gZGVjaW1hbHMoKSB2aWV3IHJldHVybnMgKHVpbnQ4KSIsImZ1bmN0aW9uIHRvdGFsU3VwcGx5KCkgdmlldyByZXR1cm5zICh1aW50MjU2KSIsImZ1bmN0aW9uIGJhbGFuY2VPZihhZGRyZXNzKSB2aWV3IHJldHVybnMgKHVpbnQpIiwiZnVuY3Rpb24gdHJhbnNmZXIoYWRkcmVzcyB0bywgdWludCBhbW91bnQpIiwiZnVuY3Rpb24gdHJhbnNmZXJGcm9tKGFkZHJlc3Mgc2VuZGVyLCBhZGRyZXNzIHJlY2lwaWVudCwgdWludDI1NiBhbW91bnQpIGV4dGVybmFsIHJldHVybnMgKGJvb2wpIiwiZnVuY3Rpb24gbWludChhZGRyZXNzIHRvLCB1aW50MjU2IGFtb3VudCkiLCJldmVudCBUcmFuc2ZlcihhZGRyZXNzIGluZGV4ZWQgZnJvbSwgYWRkcmVzcyBpbmRleGVkIHRvLCB1aW50IGFtb3VudCkiLCJldmVudCBBcHByb3ZhbChhZGRyZXNzIGluZGV4ZWQgb3duZXIsIGFkZHJlc3MgaW5kZXhlZCBzcGVuZGVyLCB1aW50MjU2IHZhbHVlKSJd::W10=', 
                address = 0xdac17f958d2ee523a2206206994597c13d831ec7
            )
        else :
            return SmartBchContractResponse(
        )

    def testSmartBchContractResponse(self):
        """Test SmartBchContractResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class GetAddressesResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bchtest': 'str',
        'slptest': 'str',
        'sbchtest': 'str',
        'sbchcontract': 'str',
        'sbchtoken': 'str'
    }

    attribute_map = {
        'bchtest': 'bchtest',
        'slptest': 'slptest',
        'sbchtest': 'sbchtest',
        'sbchcontract': 'sbchcontract',
        'sbchtoken': 'sbchtoken'
    }

    def __init__(self, bchtest=None, slptest=None, sbchtest=None, sbchcontract=None, sbchtoken=None, local_vars_configuration=None):  # noqa: E501
        """GetAddressesResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bchtest = None
        self._slptest = None
        self._sbchtest = None
        self._sbchcontract = None
        self._sbchtoken = None
        self.discriminator = None

        if bchtest is not None:
            self.bchtest = bchtest
        if slptest is not None:
            self.slptest = slptest
        if sbchtest is not None:
            self.sbchtest = sbchtest
        if sbchcontract is not None:
            self.sbchcontract = sbchcontract
        if sbchtoken is not None:
            self.sbchtoken = sbchtoken

    @property
    def bchtest(self):
        """Gets the bchtest of this GetAddressesResponse.  # noqa: E501

        Cashaddr to return testnet BCH  # noqa: E501

        :return: The bchtest of this GetAddressesResponse.  # noqa: E501
        :rtype: str
        """
        return self._bchtest

    @bchtest.setter
    def bchtest(self, bchtest):
        """Sets the bchtest of this GetAddressesResponse.

        Cashaddr to return testnet BCH  # noqa: E501

        :param bchtest: The bchtest of this GetAddressesResponse.  # noqa: E501
        :type bchtest: str
        """

        self._bchtest = bchtest

    @property
    def slptest(self):
        """Gets the slptest of this GetAddressesResponse.  # noqa: E501

        Slpaddr to return testnet SLP tokens  # noqa: E501

        :return: The slptest of this GetAddressesResponse.  # noqa: E501
        :rtype: str
        """
        return self._slptest

    @slptest.setter
    def slptest(self, slptest):
        """Sets the slptest of this GetAddressesResponse.

        Slpaddr to return testnet SLP tokens  # noqa: E501

        :param slptest: The slptest of this GetAddressesResponse.  # noqa: E501
        :type slptest: str
        """

        self._slptest = slptest

    @property
    def sbchtest(self):
        """Gets the sbchtest of this GetAddressesResponse.  # noqa: E501

        SmartBch testnet faucet contract owner address  # noqa: E501

        :return: The sbchtest of this GetAddressesResponse.  # noqa: E501
        :rtype: str
        """
        return self._sbchtest

    @sbchtest.setter
    def sbchtest(self, sbchtest):
        """Sets the sbchtest of this GetAddressesResponse.

        SmartBch testnet faucet contract owner address  # noqa: E501

        :param sbchtest: The sbchtest of this GetAddressesResponse.  # noqa: E501
        :type sbchtest: str
        """

        self._sbchtest = sbchtest

    @property
    def sbchcontract(self):
        """Gets the sbchcontract of this GetAddressesResponse.  # noqa: E501

        SmartBch testnet contract address to return BCH and SEP20 tokens  # noqa: E501

        :return: The sbchcontract of this GetAddressesResponse.  # noqa: E501
        :rtype: str
        """
        return self._sbchcontract

    @sbchcontract.setter
    def sbchcontract(self, sbchcontract):
        """Sets the sbchcontract of this GetAddressesResponse.

        SmartBch testnet contract address to return BCH and SEP20 tokens  # noqa: E501

        :param sbchcontract: The sbchcontract of this GetAddressesResponse.  # noqa: E501
        :type sbchcontract: str
        """

        self._sbchcontract = sbchcontract

    @property
    def sbchtoken(self):
        """Gets the sbchtoken of this GetAddressesResponse.  # noqa: E501

        SmartBch testnet sample SEP20 token address  # noqa: E501

        :return: The sbchtoken of this GetAddressesResponse.  # noqa: E501
        :rtype: str
        """
        return self._sbchtoken

    @sbchtoken.setter
    def sbchtoken(self, sbchtoken):
        """Sets the sbchtoken of this GetAddressesResponse.

        SmartBch testnet sample SEP20 token address  # noqa: E501

        :param sbchtoken: The sbchtoken of this GetAddressesResponse.  # noqa: E501
        :type sbchtoken: str
        """

        self._sbchtoken = sbchtoken

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAddressesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetAddressesResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class BalanceRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'wallet_id': 'str',
        'slp_aware': 'bool',
        'slp_semi_aware': 'bool'
    }

    attribute_map = {
        'wallet_id': 'walletId',
        'slp_aware': 'slpAware',
        'slp_semi_aware': 'slpSemiAware'
    }

    def __init__(self, wallet_id=None, slp_aware=False, slp_semi_aware=False, local_vars_configuration=None):  # noqa: E501
        """BalanceRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._wallet_id = None
        self._slp_aware = None
        self._slp_semi_aware = None
        self.discriminator = None

        self.wallet_id = wallet_id
        if slp_aware is not None:
            self.slp_aware = slp_aware
        if slp_semi_aware is not None:
            self.slp_semi_aware = slp_semi_aware

    @property
    def wallet_id(self):
        """Gets the wallet_id of this BalanceRequest.  # noqa: E501

        The walletId to get a balance for.   # noqa: E501

        :return: The wallet_id of this BalanceRequest.  # noqa: E501
        :rtype: str
        """
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, wallet_id):
        """Sets the wallet_id of this BalanceRequest.

        The walletId to get a balance for.   # noqa: E501

        :param wallet_id: The wallet_id of this BalanceRequest.  # noqa: E501
        :type wallet_id: str
        """
        if self.local_vars_configuration.client_side_validation and wallet_id is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_id`, must not be `None`")  # noqa: E501

        self._wallet_id = wallet_id

    @property
    def slp_aware(self):
        """Gets the slp_aware of this BalanceRequest.  # noqa: E501

        If you have any SLP tokens on the address, you should set `slpAware` to `true` to prevent accidental token burning This flag activates utxo checking against an external slp indexer So far this option is not switched on by default  # noqa: E501

        :return: The slp_aware of this BalanceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._slp_aware

    @slp_aware.setter
    def slp_aware(self, slp_aware):
        """Sets the slp_aware of this BalanceRequest.

        If you have any SLP tokens on the address, you should set `slpAware` to `true` to prevent accidental token burning This flag activates utxo checking against an external slp indexer So far this option is not switched on by default  # noqa: E501

        :param slp_aware: The slp_aware of this BalanceRequest.  # noqa: E501
        :type slp_aware: bool
        """

        self._slp_aware = slp_aware

    @property
    def slp_semi_aware(self):
        """Gets the slp_semi_aware of this BalanceRequest.  # noqa: E501

        This flag requires an utxo to have more than 546 sats to be spendable and counted in the balance This option is not switched on by default  # noqa: E501

        :return: The slp_semi_aware of this BalanceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._slp_semi_aware

    @slp_semi_aware.setter
    def slp_semi_aware(self, slp_semi_aware):
        """Sets the slp_semi_aware of this BalanceRequest.

        This flag requires an utxo to have more than 546 sats to be spendable and counted in the balance This option is not switched on by default  # noqa: E501

        :param slp_semi_aware: The slp_semi_aware of this BalanceRequest.  # noqa: E501
        :type slp_semi_aware: bool
        """

        self._slp_semi_aware = slp_semi_aware

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BalanceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BalanceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SmartBchTransactionReceipt(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        '_from': 'str',
        'contract_address': 'str',
        'transaction_index': 'float',
        'root': 'str',
        'gas_used': 'str',
        'logs_bloom': 'str',
        'block_hash': 'str',
        'transaction_hash': 'str',
        'logs': 'list[object]',
        'block_number': 'float',
        'confirmations': 'float',
        'cumulative_gas_used': 'str',
        'effective_gas_price': 'str',
        'byzantium': 'bool',
        'type': 'float',
        'status': 'float'
    }

    attribute_map = {
        'to': 'to',
        '_from': 'from',
        'contract_address': 'contractAddress',
        'transaction_index': 'transactionIndex',
        'root': 'root',
        'gas_used': 'gasUsed',
        'logs_bloom': 'logsBloom',
        'block_hash': 'blockHash',
        'transaction_hash': 'transactionHash',
        'logs': 'logs',
        'block_number': 'blockNumber',
        'confirmations': 'confirmations',
        'cumulative_gas_used': 'cumulativeGasUsed',
        'effective_gas_price': 'effectiveGasPrice',
        'byzantium': 'byzantium',
        'type': 'type',
        'status': 'status'
    }

    def __init__(self, to=None, _from=None, contract_address=None, transaction_index=None, root=None, gas_used=None, logs_bloom=None, block_hash=None, transaction_hash=None, logs=None, block_number=None, confirmations=None, cumulative_gas_used=None, effective_gas_price=None, byzantium=None, type=None, status=None, local_vars_configuration=None):  # noqa: E501
        """SmartBchTransactionReceipt - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._to = None
        self.__from = None
        self._contract_address = None
        self._transaction_index = None
        self._root = None
        self._gas_used = None
        self._logs_bloom = None
        self._block_hash = None
        self._transaction_hash = None
        self._logs = None
        self._block_number = None
        self._confirmations = None
        self._cumulative_gas_used = None
        self._effective_gas_price = None
        self._byzantium = None
        self._type = None
        self._status = None
        self.discriminator = None

        self.to = to
        self._from = _from
        self.contract_address = contract_address
        self.transaction_index = transaction_index
        if root is not None:
            self.root = root
        self.gas_used = gas_used
        self.logs_bloom = logs_bloom
        self.block_hash = block_hash
        self.transaction_hash = transaction_hash
        self.logs = logs
        self.block_number = block_number
        self.confirmations = confirmations
        self.cumulative_gas_used = cumulative_gas_used
        self.effective_gas_price = effective_gas_price
        self.byzantium = byzantium
        self.type = type
        if status is not None:
            self.status = status

    @property
    def to(self):
        """Gets the to of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The to of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this SmartBchTransactionReceipt.


        :param to: The to of this SmartBchTransactionReceipt.  # noqa: E501
        :type to: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def _from(self):
        """Gets the _from of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The _from of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SmartBchTransactionReceipt.


        :param _from: The _from of this SmartBchTransactionReceipt.  # noqa: E501
        :type _from: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def contract_address(self):
        """Gets the contract_address of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The contract_address of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._contract_address

    @contract_address.setter
    def contract_address(self, contract_address):
        """Sets the contract_address of this SmartBchTransactionReceipt.


        :param contract_address: The contract_address of this SmartBchTransactionReceipt.  # noqa: E501
        :type contract_address: str
        """
        if self.local_vars_configuration.client_side_validation and contract_address is None:  # noqa: E501
            raise ValueError("Invalid value for `contract_address`, must not be `None`")  # noqa: E501

        self._contract_address = contract_address

    @property
    def transaction_index(self):
        """Gets the transaction_index of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The transaction_index of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: float
        """
        return self._transaction_index

    @transaction_index.setter
    def transaction_index(self, transaction_index):
        """Sets the transaction_index of this SmartBchTransactionReceipt.


        :param transaction_index: The transaction_index of this SmartBchTransactionReceipt.  # noqa: E501
        :type transaction_index: float
        """
        if self.local_vars_configuration.client_side_validation and transaction_index is None:  # noqa: E501
            raise ValueError("Invalid value for `transaction_index`, must not be `None`")  # noqa: E501

        self._transaction_index = transaction_index

    @property
    def root(self):
        """Gets the root of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The root of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._root

    @root.setter
    def root(self, root):
        """Sets the root of this SmartBchTransactionReceipt.


        :param root: The root of this SmartBchTransactionReceipt.  # noqa: E501
        :type root: str
        """

        self._root = root

    @property
    def gas_used(self):
        """Gets the gas_used of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The gas_used of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._gas_used

    @gas_used.setter
    def gas_used(self, gas_used):
        """Sets the gas_used of this SmartBchTransactionReceipt.


        :param gas_used: The gas_used of this SmartBchTransactionReceipt.  # noqa: E501
        :type gas_used: str
        """
        if self.local_vars_configuration.client_side_validation and gas_used is None:  # noqa: E501
            raise ValueError("Invalid value for `gas_used`, must not be `None`")  # noqa: E501

        self._gas_used = gas_used

    @property
    def logs_bloom(self):
        """Gets the logs_bloom of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The logs_bloom of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._logs_bloom

    @logs_bloom.setter
    def logs_bloom(self, logs_bloom):
        """Sets the logs_bloom of this SmartBchTransactionReceipt.


        :param logs_bloom: The logs_bloom of this SmartBchTransactionReceipt.  # noqa: E501
        :type logs_bloom: str
        """
        if self.local_vars_configuration.client_side_validation and logs_bloom is None:  # noqa: E501
            raise ValueError("Invalid value for `logs_bloom`, must not be `None`")  # noqa: E501

        self._logs_bloom = logs_bloom

    @property
    def block_hash(self):
        """Gets the block_hash of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The block_hash of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._block_hash

    @block_hash.setter
    def block_hash(self, block_hash):
        """Sets the block_hash of this SmartBchTransactionReceipt.


        :param block_hash: The block_hash of this SmartBchTransactionReceipt.  # noqa: E501
        :type block_hash: str
        """
        if self.local_vars_configuration.client_side_validation and block_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `block_hash`, must not be `None`")  # noqa: E501

        self._block_hash = block_hash

    @property
    def transaction_hash(self):
        """Gets the transaction_hash of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The transaction_hash of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._transaction_hash

    @transaction_hash.setter
    def transaction_hash(self, transaction_hash):
        """Sets the transaction_hash of this SmartBchTransactionReceipt.


        :param transaction_hash: The transaction_hash of this SmartBchTransactionReceipt.  # noqa: E501
        :type transaction_hash: str
        """
        if self.local_vars_configuration.client_side_validation and transaction_hash is None:  # noqa: E501
            raise ValueError("Invalid value for `transaction_hash`, must not be `None`")  # noqa: E501

        self._transaction_hash = transaction_hash

    @property
    def logs(self):
        """Gets the logs of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The logs of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: list[object]
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """Sets the logs of this SmartBchTransactionReceipt.


        :param logs: The logs of this SmartBchTransactionReceipt.  # noqa: E501
        :type logs: list[object]
        """
        if self.local_vars_configuration.client_side_validation and logs is None:  # noqa: E501
            raise ValueError("Invalid value for `logs`, must not be `None`")  # noqa: E501

        self._logs = logs

    @property
    def block_number(self):
        """Gets the block_number of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The block_number of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: float
        """
        return self._block_number

    @block_number.setter
    def block_number(self, block_number):
        """Sets the block_number of this SmartBchTransactionReceipt.


        :param block_number: The block_number of this SmartBchTransactionReceipt.  # noqa: E501
        :type block_number: float
        """
        if self.local_vars_configuration.client_side_validation and block_number is None:  # noqa: E501
            raise ValueError("Invalid value for `block_number`, must not be `None`")  # noqa: E501

        self._block_number = block_number

    @property
    def confirmations(self):
        """Gets the confirmations of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The confirmations of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: float
        """
        return self._confirmations

    @confirmations.setter
    def confirmations(self, confirmations):
        """Sets the confirmations of this SmartBchTransactionReceipt.


        :param confirmations: The confirmations of this SmartBchTransactionReceipt.  # noqa: E501
        :type confirmations: float
        """
        if self.local_vars_configuration.client_side_validation and confirmations is None:  # noqa: E501
            raise ValueError("Invalid value for `confirmations`, must not be `None`")  # noqa: E501

        self._confirmations = confirmations

    @property
    def cumulative_gas_used(self):
        """Gets the cumulative_gas_used of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The cumulative_gas_used of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._cumulative_gas_used

    @cumulative_gas_used.setter
    def cumulative_gas_used(self, cumulative_gas_used):
        """Sets the cumulative_gas_used of this SmartBchTransactionReceipt.


        :param cumulative_gas_used: The cumulative_gas_used of this SmartBchTransactionReceipt.  # noqa: E501
        :type cumulative_gas_used: str
        """
        if self.local_vars_configuration.client_side_validation and cumulative_gas_used is None:  # noqa: E501
            raise ValueError("Invalid value for `cumulative_gas_used`, must not be `None`")  # noqa: E501

        self._cumulative_gas_used = cumulative_gas_used

    @property
    def effective_gas_price(self):
        """Gets the effective_gas_price of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The effective_gas_price of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: str
        """
        return self._effective_gas_price

    @effective_gas_price.setter
    def effective_gas_price(self, effective_gas_price):
        """Sets the effective_gas_price of this SmartBchTransactionReceipt.


        :param effective_gas_price: The effective_gas_price of this SmartBchTransactionReceipt.  # noqa: E501
        :type effective_gas_price: str
        """
        if self.local_vars_configuration.client_side_validation and effective_gas_price is None:  # noqa: E501
            raise ValueError("Invalid value for `effective_gas_price`, must not be `None`")  # noqa: E501

        self._effective_gas_price = effective_gas_price

    @property
    def byzantium(self):
        """Gets the byzantium of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The byzantium of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: bool
        """
        return self._byzantium

    @byzantium.setter
    def byzantium(self, byzantium):
        """Sets the byzantium of this SmartBchTransactionReceipt.


        :param byzantium: The byzantium of this SmartBchTransactionReceipt.  # noqa: E501
        :type byzantium: bool
        """
        if self.local_vars_configuration.client_side_validation and byzantium is None:  # noqa: E501
            raise ValueError("Invalid value for `byzantium`, must not be `None`")  # noqa: E501

        self._byzantium = byzantium

    @property
    def type(self):
        """Gets the type of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The type of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: float
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SmartBchTransactionReceipt.


        :param type: The type of this SmartBchTransactionReceipt.  # noqa: E501
        :type type: float
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def status(self):
        """Gets the status of this SmartBchTransactionReceipt.  # noqa: E501


        :return: The status of this SmartBchTransactionReceipt.  # noqa: E501
        :rtype: float
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SmartBchTransactionReceipt.


        :param status: The status of this SmartBchTransactionReceipt.  # noqa: E501
        :type status: float
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartBchTransactionReceipt):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmartBchTransactionReceipt):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.smartbch_wallet_api import SmartbchWalletApi  # noqa: E501
from mainnet.rest import ApiException


class TestSmartbchWalletApi(unittest.TestCase):
    """SmartbchWalletApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.smartbch_wallet_api.SmartbchWalletApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_smartbch_balance(self):
        """Test case for smartbch_balance

        Get total balance for wallet  # noqa: E501
        """
        pass

    def test_smartbch_create_wallet(self):
        """Test case for smartbch_create_wallet

        create a new wallet  # noqa: E501
        """
        pass

    def test_smartbch_deposit_address(self):
        """Test case for smartbch_deposit_address

        Get a deposit address  # noqa: E501
        """
        pass

    def test_smartbch_deposit_qr(self):
        """Test case for smartbch_deposit_qr

        Get receiving cash address as a qrcode  # noqa: E501
        """
        pass

    def test_smartbch_max_amount_to_send(self):
        """Test case for smartbch_max_amount_to_send

        Get maximum spendable amount  # noqa: E501
        """
        pass

    def test_smartbch_send(self):
        """Test case for smartbch_send

        Send some amount to a given address  # noqa: E501
        """
        pass

    def test_smartbch_send_max(self):
        """Test case for smartbch_send_max

        Send all available funds to a given address  # noqa: E501
        """
        pass

    def test_smartbch_signed_message_sign(self):
        """Test case for smartbch_signed_message_sign

        Returns the message signature  # noqa: E501
        """
        pass

    def test_smartbch_signed_message_verify(self):
        """Test case for smartbch_signed_message_verify

        Returns a boolean indicating whether message was valid for a given address  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.smartbch_sep20_api import SmartbchSep20Api  # noqa: E501
from mainnet.rest import ApiException


class TestSmartbchSep20Api(unittest.TestCase):
    """SmartbchSep20Api unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.smartbch_sep20_api.SmartbchSep20Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_smart_bch_sep20_all_balances(self):
        """Test case for smart_bch_sep20_all_balances

        Get all SmartBch SEP20 balances of the wallet  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_balance(self):
        """Test case for smart_bch_sep20_balance

        Get total SmartBch SEP20 token balance of the wallet  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_deposit_address(self):
        """Test case for smart_bch_sep20_deposit_address

        Get an SmartBch SEP20 deposit address  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_deposit_qr(self):
        """Test case for smart_bch_sep20_deposit_qr

        Get an SmartBch SEP20 receiving address as a qrcode  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_genesis(self):
        """Test case for smart_bch_sep20_genesis

        Get created tokenId back and new SmartBch SEP20 token balance of the wallet  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_mint(self):
        """Test case for smart_bch_sep20_mint

        Get created tokenId back and new SmartBch SEP20 token balance of the wallet  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_send(self):
        """Test case for smart_bch_sep20_send

        Send some SmartBch SEP20 token amount to a given address  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_send_max(self):
        """Test case for smart_bch_sep20_send_max

        Send all available SmartBch SEP20 token funds to a given address  # noqa: E501
        """
        pass

    def test_smart_bch_sep20_token_info(self):
        """Test case for smart_bch_sep20_token_info

        Get information about the SmartBch SEP20 token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.util_api import UtilApi  # noqa: E501
from mainnet.rest import ApiException


class TestUtilApi(unittest.TestCase):
    """UtilApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.util_api.UtilApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_convert(self):
        """Test case for convert

        convert between units  # noqa: E501
        """
        pass

    def test_get_addrs_by_xpub_key(self):
        """Test case for get_addrs_by_xpub_key

        Derive heristic determined addresses from an extended public key, per BIP32  # noqa: E501
        """
        pass

    def test_get_xpub_key_info(self):
        """Test case for get_xpub_key_info

        Decode information about an extended public key, per BIP32  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mainnet.api_client import ApiClient
from mainnet.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContractApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def contract_fn(self, contract_fn_request, **kwargs):  # noqa: E501
        """Call a method on a contract  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_fn(contract_fn_request, async_req=True)
        >>> result = thread.get()

        :param contract_fn_request: Request a new cashscript contract (required)
        :type contract_fn_request: ContractFnRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ContractFnResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.contract_fn_with_http_info(contract_fn_request, **kwargs)  # noqa: E501

    def contract_fn_with_http_info(self, contract_fn_request, **kwargs):  # noqa: E501
        """Call a method on a contract  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_fn_with_http_info(contract_fn_request, async_req=True)
        >>> result = thread.get()

        :param contract_fn_request: Request a new cashscript contract (required)
        :type contract_fn_request: ContractFnRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ContractFnResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'contract_fn_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method contract_fn" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'contract_fn_request' is set
        if self.api_client.client_side_validation and ('contract_fn_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['contract_fn_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contract_fn_request` when calling `contract_fn`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contract_fn_request' in local_var_params:
            body_params = local_var_params['contract_fn_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/contract/call', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContractFnResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def contract_info(self, contract_info_request, **kwargs):  # noqa: E501
        """Get information about a contract from the contractId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_info(contract_info_request, async_req=True)
        >>> result = thread.get()

        :param contract_info_request: Request parsed information regarding a contract from the contractId (required)
        :type contract_info_request: ContractInfoRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ContractInfoResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.contract_info_with_http_info(contract_info_request, **kwargs)  # noqa: E501

    def contract_info_with_http_info(self, contract_info_request, **kwargs):  # noqa: E501
        """Get information about a contract from the contractId  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_info_with_http_info(contract_info_request, async_req=True)
        >>> result = thread.get()

        :param contract_info_request: Request parsed information regarding a contract from the contractId (required)
        :type contract_info_request: ContractInfoRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ContractInfoResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'contract_info_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method contract_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'contract_info_request' is set
        if self.api_client.client_side_validation and ('contract_info_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['contract_info_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contract_info_request` when calling `contract_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contract_info_request' in local_var_params:
            body_params = local_var_params['contract_info_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/contract/info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContractInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def contract_utxos(self, contract, **kwargs):  # noqa: E501
        """List specific utxos on any contract  # noqa: E501

        Returns all UTXOs that can be spent by the contract. Both confirmed and unconfirmed UTXOs are included. The endpoint works with contracts generated from templates (i.e. escrow).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_utxos(contract, async_req=True)
        >>> result = thread.get()

        :param contract: (required)
        :type contract: Contract
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UtxoResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.contract_utxos_with_http_info(contract, **kwargs)  # noqa: E501

    def contract_utxos_with_http_info(self, contract, **kwargs):  # noqa: E501
        """List specific utxos on any contract  # noqa: E501

        Returns all UTXOs that can be spent by the contract. Both confirmed and unconfirmed UTXOs are included. The endpoint works with contracts generated from templates (i.e. escrow).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.contract_utxos_with_http_info(contract, async_req=True)
        >>> result = thread.get()

        :param contract: (required)
        :type contract: Contract
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UtxoResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'contract'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method contract_utxos" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ('contract' not in local_var_params or  # noqa: E501
                                                        local_var_params['contract'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contract` when calling `contract_utxos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contract' in local_var_params:
            body_params = local_var_params['contract']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/contract/utxos', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UtxoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def create_contract(self, contract_request, **kwargs):  # noqa: E501
        """Create a cashscript contract  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_contract(contract_request, async_req=True)
        >>> result = thread.get()

        :param contract_request: Request a new cashscript contract (required)
        :type contract_request: ContractRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ContractResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.create_contract_with_http_info(contract_request, **kwargs)  # noqa: E501

    def create_contract_with_http_info(self, contract_request, **kwargs):  # noqa: E501
        """Create a cashscript contract  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_contract_with_http_info(contract_request, async_req=True)
        >>> result = thread.get()

        :param contract_request: Request a new cashscript contract (required)
        :type contract_request: ContractRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ContractResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'contract_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_contract" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'contract_request' is set
        if self.api_client.client_side_validation and ('contract_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['contract_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contract_request` when calling `create_contract`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contract_request' in local_var_params:
            body_params = local_var_params['contract_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/contract/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContractResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.5.3
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SmartBchSendResponseItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tx_id': 'str',
        'balance': 'BalanceResponse',
        'explorer_url': 'str'
    }

    attribute_map = {
        'tx_id': 'txId',
        'balance': 'balance',
        'explorer_url': 'explorerUrl'
    }

    def __init__(self, tx_id=None, balance=None, explorer_url=None, local_vars_configuration=None):  # noqa: E501
        """SmartBchSendResponseItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tx_id = None
        self._balance = None
        self._explorer_url = None
        self.discriminator = None

        if tx_id is not None:
            self.tx_id = tx_id
        if balance is not None:
            self.balance = balance
        if explorer_url is not None:
            self.explorer_url = explorer_url

    @property
    def tx_id(self):
        """Gets the tx_id of this SmartBchSendResponseItem.  # noqa: E501

        The hash of a transaction  # noqa: E501

        :return: The tx_id of this SmartBchSendResponseItem.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this SmartBchSendResponseItem.

        The hash of a transaction  # noqa: E501

        :param tx_id: The tx_id of this SmartBchSendResponseItem.  # noqa: E501
        :type tx_id: str
        """

        self._tx_id = tx_id

    @property
    def balance(self):
        """Gets the balance of this SmartBchSendResponseItem.  # noqa: E501


        :return: The balance of this SmartBchSendResponseItem.  # noqa: E501
        :rtype: BalanceResponse
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this SmartBchSendResponseItem.


        :param balance: The balance of this SmartBchSendResponseItem.  # noqa: E501
        :type balance: BalanceResponse
        """

        self._balance = balance

    @property
    def explorer_url(self):
        """Gets the explorer_url of this SmartBchSendResponseItem.  # noqa: E501

        Web url to a transaction on a block explorer  # noqa: E501

        :return: The explorer_url of this SmartBchSendResponseItem.  # noqa: E501
        :rtype: str
        """
        return self._explorer_url

    @explorer_url.setter
    def explorer_url(self, explorer_url):
        """Sets the explorer_url of this SmartBchSendResponseItem.

        Web url to a transaction on a block explorer  # noqa: E501

        :param explorer_url: The explorer_url of this SmartBchSendResponseItem.  # noqa: E501
        :type explorer_url: str
        """

        self._explorer_url = explorer_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmartBchSendResponseItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmartBchSendResponseItem):
            return True

        return self.to_dict() != other.to_dict()
